==> axiom-1.4.0-src.zip: axiom-1.4.0/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestGetXMLStreamReaderWithPreserveNamespaceContext2.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.om.element;

import static com.google.common.truth.Truth.assertThat;

import javax.xml.stream.XMLStreamReader;

import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMMetaFactory;
import org.apache.axiom.om.OMXMLBuilderFactory;
import org.apache.axiom.om.OMXMLStreamReaderConfiguration;
import org.apache.axiom.ts.AxiomTestCase;

/**
 * Tests the behavior of
 * {@link OMElement#getXMLStreamReader(boolean, OMXMLStreamReaderConfiguration)} when
 * {@link OMXMLStreamReaderConfiguration#isPreserveNamespaceContext()} is {@code true} and there are
 * masked or redundant namespace declarations. This is a regression test for
 * <a href="https://issues.apache.org/jira/browse/AXIOM-485">AXIOM-485</a>.
 */
public class TestGetXMLStreamReaderWithPreserveNamespaceContext2 extends AxiomTestCase {
    public TestGetXMLStreamReaderWithPreserveNamespaceContext2(OMMetaFactory metaFactory) {
        super(metaFactory);
    }

    @Override
    protected void runTest() throws Throwable {
        OMElement root = OMXMLBuilderFactory.createOMBuilder(metaFactory.getOMFactory(),
                TestGetXMLStreamReaderWithPreserveNamespaceContext2.class.getResourceAsStream("AXIOM-485.xml")).getDocumentElement();
        OMElement child = root.getFirstElement();
        OMXMLStreamReaderConfiguration configuration = new OMXMLStreamReaderConfiguration();
        configuration.setPreserveNamespaceContext(true);
        XMLStreamReader reader = child.getXMLStreamReader(true, configuration);
        reader.next();
        assertThat(reader.isStartElement()).isTrue();
        assertThat(reader.getNamespaceCount()).isEqualTo(1);
        assertThat(reader.getNamespacePrefix(0)).isEqualTo("p");
        assertThat(reader.getNamespaceURI(0)).isEqualTo("urn:ns2");
    }
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/element/TestGetXMLStreamReaderWithPreserveNamespaceContext2.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.om.element;

import static com.google.common.truth.Truth.assertThat;

import javax.xml.stream.XMLStreamReader;

import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMMetaFactory;
import org.apache.axiom.om.OMXMLBuilderFactory;
import org.apache.axiom.om.OMXMLStreamReaderConfiguration;
import org.apache.axiom.ts.AxiomTestCase;

/**
 * Tests the behavior of {@link OMElement#getXMLStreamReader(boolean,
 * OMXMLStreamReaderConfiguration)} when {@link
 * OMXMLStreamReaderConfiguration#isPreserveNamespaceContext()} is {@code true} and there are masked
 * or redundant namespace declarations. This is a regression test for <a
 * href="https://issues.apache.org/jira/browse/AXIOM-485">AXIOM-485</a>.
 */
public class TestGetXMLStreamReaderWithPreserveNamespaceContext2 extends AxiomTestCase {
    public TestGetXMLStreamReaderWithPreserveNamespaceContext2(OMMetaFactory metaFactory) {
        super(metaFactory);
    }

    @Override
    protected void runTest() throws Throwable {
        OMElement root =
                OMXMLBuilderFactory.createOMBuilder(
                                metaFactory.getOMFactory(),
                                TestGetXMLStreamReaderWithPreserveNamespaceContext2.class
                                        .getResourceAsStream("AXIOM-485.xml"))
                        .getDocumentElement();
        OMElement child = root.getFirstElement();
        OMXMLStreamReaderConfiguration configuration = new OMXMLStreamReaderConfiguration();
        configuration.setPreserveNamespaceContext(true);
        XMLStreamReader reader = child.getXMLStreamReader(true, configuration);
        reader.next();
        assertThat(reader.isStartElement()).isTrue();
        assertThat(reader.getNamespaceCount()).isEqualTo(1);
        assertThat(reader.getNamespacePrefix(0)).isEqualTo("p");
        assertThat(reader.getNamespaceURI(0)).isEqualTo("urn:ns2");
    }
}
